@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1102';
+our $VERSION = '0.1103';
 
 use List::MoreUtils qw/ any first_index /;
 use Moo;
@@ -278,7 +278,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1102
+version 0.1103
 
 =head1 SYNOPSIS
 
@@ -338,6 +338,10 @@ Note on which the scale is based.  Default: C<C>
 This must be an uppercase letter from A-G either alone or followed by
 C<#> or C<b>.
 
+Note that the keys of C<A#>, C<D#>, C<E#> and C<Fb> are better
+represented by C<Gb>, C<Eb>, C<F> and C<E> respectively, because they
+contain notes with double accidentals.
+
 =head2 scale_name
 
 Name of the scale.  Default: C<major>
